.. :changelog:

History
-------

0.0.1 (24-12-2017)
---------------------

* First code creation


4.0.0 (05-03-2019)
------------------

* Removed authentication mechanism and made the service expect an authenticated pickled requests session


4.0.1 (06-03-2019)
------------------

* Removed wrongly placed files in the root of the virtual environment


4.0.2 (07-07-2019)
------------------

* Fixes issue when the battery level is not reported by specific brands of mobiles


4.1.0 (01-09-2019)
------------------

* Implemented support for text based cookies compatible with curl and wget that can be retrieved from addons from the browser.


4.1.1 (22-04-2020)
------------------

* Updated endpoint to rpc from preview and updated dependencies.



4.1.3 (01-01-2021)
------------------

* Changed to authuser setting "2" and loosened up pinning of dependencies.


4.1.4 (01-01-2021)
------------------

* Releasing with changes.


4.1.5 (01-01-2021)
------------------

* Aligning New Year's morning blunder release with git tag


4.1.6 (24-02-2021)
------------------

* More verbose debug messages (courtesy of Dmitry Katsubo <dmitry.katsubo@gmail.com>) and bumped dependencies.


4.1.7 (07-07-2021)
------------------

* Bumped dependencies.


4.1.8 (07-07-2021)
------------------

* Pinned Pipfile version to 3.7


4.1.9 (01-03-2023)
------------------

* Implement default values for cookies.


4.2.0 (01-03-2023)
------------------

* Expose more details.


5.0.0 (04-04-2023)
------------------

* Implement better session validation heuristic, checking from cookies. Remove obsolete pickle cookie loading.
